<?php

if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly
}

class Diller_App
{
  private static $instance = null;

  private function __construct()
  {
    $this->define_constants();
    $this->includes();
  }

  public static function instance()
  {
    if (null === self::$instance) {
      self::$instance = new self();
    }
    return self::$instance;
  }

  private function define_constants()
  {
    // urls
    define('DILLERAPP_ASSETS_URL', DILLERAPP_URL . 'assets/');
    define('DILLERAPP_ASSETS_IMG_URL', DILLERAPP_ASSETS_URL . 'images/');
    define('DILLERAPP_ASSETS_JS_URL', DILLERAPP_ASSETS_URL . 'js/');
    define('DILLERAPP_ASSETS_CSS_URL', DILLERAPP_ASSETS_URL . 'css/');

    // pathes
    define('DILLERAPP_ASSETS_DIR', DILLERAPP_ABSPATH . 'assets/');
    define('DILLERAPP_ASSETS_IMG_DIR', DILLERAPP_ASSETS_DIR . 'images/');
    define('DILLERAPP_ASSETS_JS_DIR', DILLERAPP_ASSETS_DIR . 'js/');
    define('DILLERAPP_ASSETS_CSS_DIR', DILLERAPP_ASSETS_DIR . 'css/');
  }

  private function includes()
  {

    require_once(DILLERAPP_DIR . 'diller_wp_admin.php');
    require_once(DILLERAPP_DIR . 'module/coupons.php');
    require_once(DILLERAPP_DIR . 'module/stamp_card.php');
    require_once(DILLERAPP_DIR . 'module/refer_friend.php');
    require_once(DILLERAPP_DIR . 'module/subscription.php');
    require_once(DILLERAPP_DIR . 'module/single_coupon.php');
    require_once(DILLERAPP_DIR . 'module/single_stampcard.php');
    require_once(DILLERAPP_DIR . 'module/cart_coupon.php');
    require_once(DILLERAPP_DIR . 'class/class.dillerapp.php');
    require_once(DILLERAPP_DIR . 'class/class-diller-user.php');
  }

  public function plugins_loaded()
  {

    $this->init_hooks();  
    $this->check_refer_status();
  }



  private function check_refer_status()
  {
    $admin_response = Dillerapp::diller_wc_admin_details();
    if ($admin_response) {
      $request = array(
        'store_id' => $admin_response['store_id']
      );

      $data = http_build_query($request);
      $res = Dillerapp::get_store_details();

      if ($res && $res->status == 200) {
        if ($res->result->plugin_refer_friend == 1) {
          
        }
      }
    }
  }

  function dillerapp_account_menu_items_new($menu_links)
  {
    $admin_response = Dillerapp::diller_wc_admin_details();
    $new = array('refer_a_friend' => ($admin_response['language'] == 2 ? 'Refer a friend' : 'Verv en venn'));
    $menu_links = array_slice($menu_links, 0, 4, true)
      + $new
      + array_slice($menu_links, 4, NULL, true);
    return $menu_links;
  }


  function dillerapp_refer_a_friend_endpoint_content_new()
  {

    $admin_response = Dillerapp::diller_wc_admin_details();
    $user_detail = Dillerapp::dillerapp_get_require_param_function();
    if (!empty($user_detail)) {
      $diller_loyalty_program_status = Dillerapp::dillerapp_checked_user_loyalty_status();
      if ($diller_loyalty_program_status == 1) {
        echo do_shortcode('[short_refer_friend store_pin= "' . $admin_response['store_id'] . '"]');
      } else {
        echo do_shortcode('[short_refer_friend]');
      }
    } else {
      echo do_shortcode('[short_refer_friend]');
    }
  }

  private function init_hooks()
  {
    add_action('admin_menu', [$this, 'dillerapp_add_admin_menu']);
  }

  function dillerapp_account_menu_items($menu_links)
  {
    $settings = get_diller_settings();

    $user_id = get_current_user_id();
    if (!$user_id) return $menu_links;

    $language = $settings['_choose_language_id'];
    if (empty($language)) return $menu_links;

    $new = array('coupons' => ($language == 2 ? 'Coupons' : 'Mine kuponger'));

    $menu_links = array_slice($menu_links, 0, 3, true)
      + $new
      + array_slice($menu_links, 3, NULL, true);

    return $menu_links;
  }
  function dillerapp_account_menu_items_stamp($menu_links)
  {
    $settings = get_diller_settings();

    $user_id = get_current_user_id();
    if (!$user_id) return $menu_links;

    $language = $settings['_choose_language_id'];
    if (empty($language)) return $menu_links;

    $new = array('stamp_card' => ($language == 2 ? 'Stamp card' : 'Mine klippekort'));

    $menu_links = array_slice($menu_links, 0, 3, true)
      + $new
      + array_slice($menu_links, 3, NULL, true);

    return $menu_links;
  } 


  function dillerapp_load_my_scripts()
  {
    wp_enqueue_script('jquery');
    if (is_page('innmelding-kundeklubb') || is_user_logged_in()) {
      wp_enqueue_style('admin-styles1', DILLERAPP_ASSETS_CSS_URL . 'diller-bootstrap.min.css', time());
      wp_enqueue_style('admin-styles12', DILLERAPP_ASSETS_CSS_URL . 'user/diller-bootstrap-select.css', time());
      wp_enqueue_style('admin-styles13', DILLERAPP_ASSETS_CSS_URL . 'bootstrap-datetimepicker.min.css', time());
    }

    $admin_response = Dillerapp::diller_wc_admin_details();
    if (empty($admin_response['skeleton_css'])) {
      wp_enqueue_style('admin-styles', DILLERAPP_ASSETS_CSS_URL . 'user/styleDiller.css', time());
    }
    $diller_store_id = $admin_response['store_id'];
    if ($admin_response['language'] == 1) {
      require_once(DILLERAPP_DIR . 'language/lang_nor.php');
    } else {
      require_once(DILLERAPP_DIR . 'language/lang_en.php');
    } ?>

     <script type="text/javascript">
      var SCRIPT_URL = '<?= plugins_url("assets/build/js/utils.js",__FILE__);?>';
      var diller_store_id = '<?= $diller_store_id ?>'; 
      var API_URL = '<?= Dillerapp::API_URL ?>';
      var diller_user_id = '<?= isset($_GET['q']) && !empty($_GET['q']) ? base64_decode($_GET['q']) : '' ?>';

    </script>
<?php
    if (is_page('innmelding-kundeklubb') || is_user_logged_in()) {
    wp_enqueue_script('script-diller', DILLERAPP_ASSETS_JS_URL . 'scriptDiller.js', array('jquery'));
    wp_enqueue_script('script-diller2', DILLERAPP_ASSETS_JS_URL . 'popper.min.js', array('jquery'));
    wp_enqueue_script('script-diller1', DILLERAPP_ASSETS_JS_URL . 'diller-bootstrap.min.js', array('jquery'));
    wp_enqueue_script('script-diller3', DILLERAPP_ASSETS_JS_URL . 'bootstrap-select.min.js', array('jquery'));
    wp_enqueue_style('intel-styles-diller', DILLERAPP_ASSETS_URL . 'build/css/intlTelInputDiller.css', time());
    wp_enqueue_script('intel-script-diller', DILLERAPP_ASSETS_URL . 'build/js/intlTelInputDiller.js', array('jquery'));
    wp_enqueue_script('datetimepicker', DILLERAPP_ASSETS_JS_URL . 'bootstrap-datetimepicker.min.js', array('jquery'));
  }
   if (is_page('innmelding-kundeklubb')){
    wp_enqueue_script( 'jquery-validate', plugins_url('assets/js/jquery-validation/jquery.validate.js', __FILE__), array('jquery', 'jquery-ui-core' ) );
    wp_enqueue_script( 'jquery-validate-min', plugins_url('assets/js/jquery-validation/jquery.validate.min.js', __FILE__), array('jquery', 'jquery-ui-core' ) );
    wp_enqueue_script( 'jquery-additional-validate', plugins_url('assets/js/jquery-validation/additional-methods.js', __FILE__), array('jquery', 'jquery-ui-core' ) );
    wp_enqueue_script( 'jquery-additional-validate-min', plugins_url('assets/js/jquery-validation/additional-methods.min.js', __FILE__), array('jquery', 'jquery-ui-core' ) );
  }
  }


  function dillerapp_add_order_delivery_date_to_order($order_id)
  {

    if (isset($_POST['privacy_policy']) && $_POST['privacy_policy'] != '') {
      $privacy_policy = sanitize_text_field($_POST['privacy_policy']);
      add_post_meta($order_id, 'loyalty_program',  $privacy_policy);
    }
    if (isset($_POST['receive_sms']) &&  $_POST['receive_sms'] != '') {
      $custom_sms = sanitize_text_field($_POST['receive_sms']);
      add_post_meta($order_id, 'sms_check',  $custom_sms);
    }
    if (isset($_POST['receive_email']) && $_POST['receive_email'] != '') {
      $custom_email = sanitize_email($_POST['receive_email']);
      add_post_meta($order_id, 'email_check',   $custom_email);
    }
    if (isset($_POST['is_purchase_history']) && $_POST['is_purchase_history'] != '') {
      $custom_email = sanitize_email(1);
      add_post_meta($order_id, 'is_purchase_history',   $custom_email);
    }
  }

  function dillerapp_coupons_endpoint_content()
  {
    $admin_response = Dillerapp::diller_wc_admin_details();
    if (!empty($admin_response)) {
      $store_pin = $admin_response['store_id'];
      $diller_loyalty_program_status = Dillerapp::dillerapp_checked_user_loyalty_status();
      if ($diller_loyalty_program_status == 1) {
        echo do_shortcode('[short_coupons store_pin="' . $store_pin . '"]');
      } else {
        echo do_shortcode('[short_coupons]');
      }
    } else {
      echo do_shortcode('[short_coupons]');
    }
  }

  function dillerapp_stamp_card_endpoint_content()
  {
    $admin_response = Dillerapp::diller_wc_admin_details();
    if (!empty($admin_response)) {
      $store_pin = $admin_response['store_id'];
      $diller_loyalty_program_status = Dillerapp::dillerapp_checked_user_loyalty_status();
      if ($diller_loyalty_program_status == 1) {
        echo do_shortcode('[short_stamp_card store_pin="' . $store_pin . '"]');
      } else {
        echo do_shortcode('[short_stamp_card]');
      }
    } else {
      echo do_shortcode('[short_stamp_card]');
    }
  }

  function dillerapp_add_checkbox_dimension_to_edit_account_form() {
    $user = wp_get_current_user();
    $admin_response = Dillerapp::diller_wc_admin_details();
    ?>  
      <?php $diller_loyalty_program_status=Dillerapp::dillerapp_checked_user_loyalty_status(); 
      if($diller_loyalty_program_status==1){ ?>
       <input type="hidden" name="country_code" id="country_code">    
          <div class="diller-form-group">
            <label><strong><?= PHONE; ?></strong></label>
            <input type="hidden" id="test" name="phone" class="diller-form-control" value="<?= $user->phone; ?>">
            <input type="hidden"  id="old_country" value="<?= $user->country_code; ?>">
            <input type="tel" id="phone" name="newphone" class="diller-form-control demotset" value="<?= $user->mob_no!='' ? $user->mob_no :'+47' ?>"   onkeypress="return isNumberKey(event)" onchange="resetphone()" required> 
            
            <input type="number"  id="mobileOtp" name="otp" value="<?php if (isset($_POST['otp'])) echo $_POST['otp']; ?>" class="form-input" placeholder="Enter the OTP" style="display: none;">
            <span class="diller-error" id="phone_msg"></span>
          </div>
          <?php } else {?>    
        <input type="hidden" name="country_code" id="country_code">    
          <div class="diller-form-group">
            <label><strong><?= PHONE; ?></strong></label>
            <input type="tel" id="phone" name="phone" class="diller-form-control" value="<?= $user->mob_no!='' ? $user->mob_no :'+47' ?>"  onkeypress="return isNumberKey(event)" required>
            <span class="diller-error" id="phone_error"></span>
          </div>
        <?php }
        $diller_loyalty_program_status=Dillerapp::dillerapp_checked_user_loyalty_status();      
        if($diller_loyalty_program_status==0){ ?>
          <p class="diller_red_title diller_p_tag"><?= DILLER_LOYALTY_STATUS; ?></p>
        <?php } ?>

        <?php Dillerapp::dillerapp_show_dimension_details();
          Dillerapp::dillerapp_show_checkboxes('account');
        ?> 
             
    <?php
}
  function dillerapp_cancel_order($order_id)
  {
    $admin_response = Dillerapp::diller_wc_admin_details();
    $store_id = $admin_response['store_id'];

    $login_user = Dillerapp::dillerapp_get_require_param_function();
    $login_user['store_id'] = $store_id;
    $login_user['transaction_id'] = $order_id;

    $store_req = array('transaction_id' => $order_id);
    $storeData = Dillerapp::dillerapp_post_request_function($login_user, 'PosV1/cancelTransaction');
  }

  function dillerapp_action_woocommerce_applied_coupon($coupon_code)
  {
    $admin_response = Dillerapp::diller_wc_admin_details();
    $login_user = Dillerapp::dillerapp_get_require_param_function();
    $login_user['promo_code'] = $coupon_code;

    $res = Dillerapp::dillerapp_post_request_function($login_user, 'PosV1/validateCouponPromoCode');

    if ($res ){
    if ($res && $res->success === true && $res->status == 200) {
      return true;
    } else {
      $the_coupon = new WC_Coupon($coupon_code);
      WC()->cart->remove_coupon($coupon_code);

      WC()->session->__unset('wc_notices');
      wc_add_notice($res->message,  $notice_type = 'error');
      return false;
    }
  }
}


  function dillerapp_display_extra_fields_after_billing_address()
  {
    Dillerapp::dillerapp_show_checkboxes('checkout');
  }

  function dillerapp_change_order_received_text($str, $order)
  {
    if(!$order || $order->get_id()){
      $admin_response = Dillerapp::diller_wc_admin_details();
      $body = Dillerapp::dillerapp_get_require_param_function();
      $res = Dillerapp::get_store_details();
      if ($res && $res->status == 200) {
        if ($res->result->point_system == 1) {
          $user = wp_get_current_user();
          if (empty(get_user_meta($user->ID, 'user_id', true))) {
            $privacy = get_post_meta($order->get_id(), 'loyalty_program', true);
            $order_total = get_post_meta($order->get_id(), '_order_total', true);
            $order_total_point = $order_total * $res->result->dollar_is_x_point;
            if ($privacy == 1) {
              $new_str = '<p class="diller_success_msg diller_p_tag">' . ($admin_response['language'] == 2 ? "Congratulations, you earned " . $order_total_point . " points!" : "Gratulerer, du tjente " . $order_total_point . " poeng!") . '</p>';
              return $new_str;
            } else {
              return $str;
            }
          } else {
            $privacy = get_user_meta($user->ID, 'loyalty_program', true);
            $order_total = get_post_meta($order->get_id(), '_order_total', true);
            $order_total_point = $order_total * $res->result->dollar_is_x_point;
            if ($privacy == 1) {
              $new_str = '<p class="diller_success_msg diller_p_tag">' . ($admin_response['language'] == 2 ? "Congratulations, you earned " . $order_total_point . " points!" : "Gratulerer, du tjente " . $order_total_point . " poeng!") . '</p>';
              return $new_str;
            } else {
              return $str;
            }
          }
        } else {
          return $str;
        }
      } else {
        return $str;
      }
    }
}

function dillerapp_add_content_thankyou($order_id)
  {
    $order_total = get_post_meta($order_id, '_order_total', true);
    $admin_response = Dillerapp::diller_wc_admin_details();
    $request = Dillerapp::dillerapp_get_require_param_function();
    $res = Dillerapp::get_store_details();
    if ($res && $res->status == 200) {
      if ($res->result->point_system == 1) {
        $dollar_x_point = $res->result->dollar_is_x_point ? $res->result->dollar_is_x_point : 0;
    ?> 
    <?php
     $diller_loyalty_program_status = Dillerapp::dillerapp_checked_user_loyalty_status();
      if ($diller_loyalty_program_status == 1) { ?>
        <h2 class="diller_h2_tag"><?= ($admin_response['language'] == 2 ? 'Points earned' : 'Poeng opptjent'); ?></h2>
        <table class="woocommerce-table shop_table gift_info diller_woocommerce_table">
          <tbody>
            <tr>
              <th class="diller_point_earned"><?= POINT_EARNED ?></th>
              <?php $order_total_point = $order_total * $dollar_x_point; ?>
              <th class="diller_total_point"><?php echo ($order_total_point ? $order_total_point : '0') . ' ' . POINT; ?></th>
            </tr>
          </tbody>
        </table>
<?php }
      }
    }
  }

  function dillerapp_show_earn_point_column_value_on_order_page($order)
  {
    if (!empty($order) || $order->get_id()) {
      $get_order_total = $order->get_total();
      $admin_response = Dillerapp::diller_wc_admin_details();

      if (!empty($admin_response)) {
        $body = Dillerapp::dillerapp_get_require_param_function();
        $body['order_id'] = $order->get_id();
        $res = Dillerapp::dillerapp_post_request_function($body, 'PosV1/getOrderHistoryData');
        $diller_purchase_points = 0;
        if ($res && $res->status == 200) {
          $diller_purchase_points = $res->result->purchase_points;
        }
        echo $diller_purchase_points . ' ' . POINT;
      }
    }
  }


  function dillerapp_add_point_earn_column_on_order_page($columns)
  {

    $new_columns = array();
    $admin_response = Dillerapp::diller_wc_admin_details();

    if ($admin_response) {
      foreach ($columns as $key => $name) {
        $new_columns[$key] = $name;
        // add ship-to after order status column
        if ('order-status' === $key) {
          $new_columns['order-point-earned'] =  POINT_EARNED;
        }
      }
      return $new_columns;
    }
  }



  private function app_output_buffer()
  {
    ob_start();
  }

  private function my_run_only_once()
  {

    if (get_option('my_run_only_once_01') != 'completed') {

      global $wpdb;
      $tablePosts = $wpdb->prefix . 'posts';
      $tablePostsUser = $wpdb->prefix . 'usermeta';

      $postDeleteQuery = "DELETE FROM $tablePostsUser WHERE meta_key = '_store_pin_id'";
      $postDeleteQuery1 = "DELETE FROM $tablePostsUser WHERE meta_key = 'x_api_key'";

      $wpdb->query($postDeleteQuery);
      $wpdb->query($postDeleteQuery1);
      update_option('my_run_only_once_01', 'completed');
    }
  }

  public function init()
  {
    add_action('wp_enqueue_scripts', [$this, 'dillerapp_load_my_scripts']);

    $this->app_output_buffer();
    $this->my_run_only_once();
    add_rewrite_endpoint('coupons', EP_PAGES);
    add_rewrite_endpoint('stamp_card', EP_PAGES);
    add_rewrite_endpoint('refer_a_friend', EP_PAGES);
    add_rewrite_endpoint('singlecoupon', EP_PAGES);
    add_rewrite_endpoint('singlestampcard', EP_PAGES);
    add_rewrite_endpoint('emailVerify', EP_PAGES);

    DillerApp_User::dillerapp_add_new_subscriber();
    $this->dillerapp_update_role();
    //$this->diller_update_existing_member();
  }
  

  private function dillerapp_update_role()
  {
    $users = get_users(['role'    => 'subscriber']);
    foreach ($users as $user) {
      $u = new WP_User($user->ID);
      $u->remove_role('subscriber');
      $u->add_role('customer');
    }
  }

  public function admin_init()
  {
    add_action('admin_enqueue_scripts', [$this, 'dillerapp_admin_style']);
    $this->dillerapp_diller_plugin_initialize();
    $this->dillerapp_my_plugin_activation();
  }

  private function dillerapp_my_plugin_activation()
  {

    global $user_ID, $wpdb;

    $query = $wpdb->prepare(
      'SELECT ID FROM ' . $wpdb->posts . '
        WHERE post_title = %s
        AND post_type = \'page\'',
      'Innmelding kundeklubb'
    );
    $wpdb->query($query);

    if ($wpdb->num_rows) {
      $post_id = $wpdb->get_var($query);
      $meta1 = get_post_meta($post_id, 'times', TRUE);
      $meta1++;
      update_post_meta($post_id, 'times', $meta1);
    } else {
      $new_post = array(
        'post_title' => 'Innmelding kundeklubb',
        'post_content' => '[short_subscription]',
        'post_status' => 'publish',
        'post_date' => date('Y-m-d H:i:s'),
        'post_author' => '',
        'post_type' => 'page',
      );

      $post_id = wp_insert_post($new_post);
      add_post_meta($post_id, 'times', '1');
    }
    add_option('my_plugin_activation', 'just-activated');
  }

  private function dillerapp_diller_plugin_initialize()
  {
    if (is_admin() && get_option('my_plugin_activation') == 'just-activated') {
      delete_option('my_plugin_activation');
      flush_rewrite_rules();
    }
  }

  function dillerapp_add_admin_menu()
  {
    add_menu_page(
      'diller', //page title
      'Diller Loyalty', //menu title
      'manage_options', //capabilities
      'DillerApp', //menu slug
      'dillerapp_admin_page', //function
      plugin_dir_url(__FILE__) . 'assets/images/diller_white.svg' //function
    );
  }

  function dillerapp_admin_style()
  {
    wp_enqueue_style('admin-styles', DILLERAPP_ASSETS_CSS_URL . 'diller-admin-style.css', time());
    wp_enqueue_style('admin-styles2', DILLERAPP_ASSETS_CSS_URL . 'diller-admin-style1.css', time());
    wp_enqueue_style('admin-styles1', DILLERAPP_ASSETS_CSS_URL . 'diller-bootstrap.min.css', time());
    wp_enqueue_script('admin-script3', DILLERAPP_ASSETS_JS_URL . 'diller-bootstrap.min.js', time());
    wp_enqueue_script('admin-script', DILLERAPP_ASSETS_JS_URL . 'admin.js', time());
    wp_localize_script('admin-script', 'diller', array(
      'ajaxurl' => admin_url('admin-ajax.php'),
    ));
  }

  // reserve
  public function activate()
  {
  }

  public static function deactivate()
  {
  }

  public static function uninstall()
  {
    // Nothing yet
  }

  // after woocommerce loaded
  public function woocommerce_loaded()
  {
    add_action('woocommerce_thankyou', [$this, 'dillerapp_add_content_thankyou']);

    add_action('woocommerce_my_account_my_orders_column_order-point-earned', [$this, 'dillerapp_show_earn_point_column_value_on_order_page']);
    add_action('woocommerce_after_checkout_billing_form', [$this, 'dillerapp_display_extra_fields_after_billing_address'], 10, 1);
    add_action('kco_wc_after_order_review', [$this, 'dillerapp_display_extra_fields_after_billing_address'], 10, 1);
    add_action('woocommerce_applied_coupon', [$this, 'dillerapp_action_woocommerce_applied_coupon'], 10, 3);
    add_action('woocommerce_order_status_cancelled', [$this, 'dillerapp_cancel_order'], 10, 1);
    add_action('woocommerce_edit_account_form', [$this, 'dillerapp_add_checkbox_dimension_to_edit_account_form']);
    add_action('woocommerce_account_emailVerify_endpoint', function () {
      echo do_shortcode('[short_email_verify]');
    });
    add_action('woocommerce_account_singlecoupon_endpoint', function ($id) {
      echo do_shortcode('[short_singlecoupon coupon_id = ' . $id . ']');
    });
    add_action('woocommerce_account_singlestampcard_endpoint', function ($id) {
      echo do_shortcode('[short_singlestampcard stamp_id = ' . $id . ']');
    });

    add_action('woocommerce_account_coupons_endpoint', [$this, 'dillerapp_coupons_endpoint_content']);
    add_action('woocommerce_account_stamp_card_endpoint', [$this, 'dillerapp_stamp_card_endpoint_content']);
    add_action('woocommerce_account_refer_a_friend_endpoint', [$this, 'dillerapp_refer_a_friend_endpoint_content_new']);

    add_action('woocommerce_checkout_order_processed', 'DillerApp_User::dillerapp_custom_process_order', 10, 1);
    add_action('woocommerce_before_cart', 'DillerApp_User::woocommerce_cart_coupon_list', 10, 1);
    add_action('woocommerce_save_account_details', 'DillerApp_User::dillerapp_save_loyalty_dimension_account_details', 12, 1);
    add_action('woocommerce_account_dashboard', 'DillerApp_User::dillerapp_my_dashboard_addition');

    add_action('woocommerce_checkout_update_order_meta', [$this, 'dillerapp_add_order_delivery_date_to_order'], 10, 1);

    add_filter('woocommerce_account_menu_items', [$this, 'dillerapp_account_menu_items'], 10, 1);
    add_filter('woocommerce_account_menu_items', [$this, 'dillerapp_account_menu_items_stamp'], 10, 1);
    add_filter('woocommerce_account_menu_items', [$this, 'dillerapp_account_menu_items_new'], 10, 1);
    
    
    add_filter('woocommerce_thankyou_order_received_text', [$this, 'dillerapp_change_order_received_text'], 10, 2);
    add_filter('woocommerce_save_account_details_required_fields', function ($required_fields) {
      $required_fields['phone'] = 'Mobile number';
      return $required_fields;
    });

    $admin_response = Dillerapp::diller_wc_admin_details();
    if (!empty($admin_response['store_id'])) {
      add_filter('woocommerce_my_account_my_orders_columns', [$this, 'dillerapp_add_point_earn_column_on_order_page']);
    }
  }

  public function footer()
  {
  }
} 

