<?php
/*
This functions file is developed by PCK AS
*/
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

if (!function_exists('dillerapp_errors')) {
    function dillerapp_errors()
    {
        static $wp_error; // Will hold global variable safely
        return isset($wp_error) ? $wp_error : ($wp_error = new WP_Error(null, null, null));
    }
}

if (!function_exists('get_diller_settings_from_first_admin')) {
    function get_diller_settings_from_first_admin($key)
    {
        $users = get_users(['role'    => 'administrator']);
        if (empty($users)) return false;

        $first_admin = $users[0];
        if (!is_a($first_admin, 'WP_User')) return false;
        if ($value = get_user_meta($first_admin->ID, $key, true)) {
            delete_user_meta($first_admin->ID, $key);
            return $value;
        }
        return false;
    }
}
if (!function_exists('diller_check_options_from_usermeta')) {
    function diller_check_options_from_usermeta()
    {
        $default = [
            '_choose_language_id' => 0,
            '_store_pin_id' => '',
            'x_api_key' => '',
            '_disable_skeleton_css' => 0,
            '_disable_multisite' => 0,
        ];

        $user_id = get_current_user_id();
        if ($user_id <= 0) return $default;

        foreach ($default as $key => $default_value) {
            if ($value = get_user_meta($user_id, $key, true)) {
                $default[$key] = $value;
                delete_user_meta($user_id, $key);
            } else if ($value = get_diller_settings_from_first_admin($key)) {
                $default[$key] = $value;
            }
        }

        update_option('dillerapp_settings', $default);
        return $default;
    }
}
if (!function_exists('get_diller_settings')) {
    function get_diller_settings()
    {
        $settings = get_option('dillerapp_settings', []);
        if (empty($settings)) {
            return diller_check_options_from_usermeta();
        }
        return $settings;
    }
}
if (!function_exists('dillerapp_show_error_messages')) {
    function dillerapp_show_error_messages()
    {
        if ($codes = dillerapp_errors()->get_error_codes()) {
            echo '<div class="dillerapp_errors">';
            // Loop error codes and display errors
            foreach ($codes as $code) {
                $message = dillerapp_errors()->get_error_message($code);
                echo '<span class="error">' . $message . '</span><br/>';
            }
            echo '</div>';
        }
    }
}


if (!function_exists('wp_new_user_notification')) {

    function wp_new_user_notification($user_id, $deprecated = null, $notify = 'both')
    {
        $admin_response = Dillerapp::diller_wc_admin_details();

        if ($deprecated !== null) {
            _deprecated_argument(__FUNCTION__, '4.3.1');
        }

        global $wpdb, $wp_hasher;
        $user = get_userdata($user_id);
        $blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);

        if ('admin' === $notify || empty($notify)) {
            return;
        }
        $key = wp_generate_password(20, false);

        do_action('retrieve_password_key', $user->user_login, $key);
        if (empty($wp_hasher)) {
            require_once ABSPATH . WPINC . '/class-phpass.php';
            $wp_hasher = new PasswordHash(8, true);
        }
        $hashed = time() . ':' . $wp_hasher->HashPassword($key);
        $wpdb->update($wpdb->users, array('user_activation_key' => $hashed), array('user_login' => $user->user_login));

        if ($admin_response['language'] == 2) {
            $message = sprintf(__('Hey %s'), $user->first_name) . "\r\n\r\n";
            $message .= __('We have got a new member area for our loyalty program. You can now login with the below details:') . "\r\n\r\n";
            $message .= sprintf(__('Username: %s'), $user->user_login) . "\r\n\r\n";
            $message .= __('Password: Please use forgot password functionality') . "\r\n\r\n";
            $message .= __('Login area:') . network_site_url("my-account") . "\r\n\r\n";

            wp_mail($user->user_email, sprintf(__('New Member area details'), $blogname), $message);
        } else {
            $message .= sprintf(__('Hei %s'), $user->first_name) . "\r\n\r\n";
            $message .= __('Vi har fått et nytt medlemsområde for vår kundeklubb.') . "\r\n\r\n" . ('Du kan nå logge deg inn med informasjonen nedenfor:') . "\r\n\r\n";
            $message .= sprintf(__('Brukernavn: %s'), $user->user_login) . "\r\n\r\n";
            $message .= __('Passord: Bruk glemt passordfunksjonalitet') . "\r\n\r\n" . ('Påloggingsområde:') . network_site_url("min-konto") . "\r\n\r\n" . ('Mvh Diller') . "\r\n\r\n";

            wp_mail($user->user_email, sprintf(__('Detaljer om området for nye medlemmer'), $blogname), $message);
        }
    }
}



if (!function_exists('diller_check_for_user_in_site')) {
    function diller_check_for_user_in_site($email)
    {
        $has_user = false;
        $users = new WP_User_Query(array('search' => $email));
        foreach ($users->results as $user_with_email) {
            if (diller_user_can_for_blog($user_with_email, get_current_blog_id(), "read")) {
                $has_user = true;
            } // end if;

        } // end foreach;

        // If nothing was found return false;
        return $has_user;
    } // end check_for_user_in_site;

}

if (!function_exists('diller_user_can_for_blog')) {
    function diller_user_can_for_blog($user, $blog_id, $capability)
    {
        $switched = is_multisite() ? switch_to_blog($blog_id) : false;
        $current_user = $user;
        if (empty($current_user)) {
            if ($switched) {
                restore_current_blog();
            }
            return false;
        }
        $args = array_slice(func_get_args(), 2);
        $args = array_merge(array($capability), $args);
        $can = call_user_func_array(array($current_user, 'has_cap'), $args);
        if ($switched) {
            restore_current_blog();
        }

        return $can;
    }
}

if (!function_exists('diller_new_customer_data')) {
    function diller_new_customer_data($user_email, $generated_password, $random_email)
    {
        $username = sanitize_user(current(explode('@', $user_email)), true);
        $append     = 1;
        $o_username = $username;
        while (username_exists($username)) {
            $username = $o_username . $append;
            $append++;
        }

        $new_customer_data = [
            'user_login' => $username,
            'user_pass'  => $generated_password,
            'user_email' => $random_email,
            'role'       => 'customer',
        ];

        return $new_customer_data;
    }
}
